@@ -233,7 +233,7 @@ class mtse:
         
         if checkpoint_path is not None:
             print('\t\tloading pre-trained model')
-            checkpoint = torch.load(checkpoint_path)
+            checkpoint = torch.load(checkpoint_path, map_location=self.device)
             try:
                 self.ts_encoder.load_state_dict(checkpoint['model_state_dict'])
                 self.optimizer.load_state_dict(checkpoint['optimizer_state_dict'])
@@ -318,11 +318,16 @@ class mtse:
             for train_batch, label in self.train_loader:
                 train_batch, label = train_batch.to(self.device), label.to(self.device) 
                 batch_len  = train_batch.shape[0]
-                out = self.ts_encoder(train_batch[:, :, :self.n_ts*2], train_batch[:, :, -1])
+                if self.model_type == 'regression':
+                    out = self.ts_encoder(train_batch[:, :, :self.n_ts*2], train_batch[:, :, -1])
+                else:
+                    out = self.ts_encoder(train_batch[:, :, :self.n_ts*2], train_batch[:, :, -1]).reshape(-1 ,1)
                 loss = criterion(out, label)
                 train_loss += loss.item() * batch_len
                 train_n += batch_len
                 self.optimizer.zero_grad()
+                if lossf == "accuracy":
+                    loss = -loss
                 loss.backward()
                 self.optimizer.step()
 
@@ -420,7 +425,7 @@ class mtse:
         else:
             try:
                 print('\t\t loading saved weights of the pretrained model.')
-                pt_model = torch.load(checkpoint)
+                pt_model = torch.load(checkpoint, map_location=self.device)
             except:
                 raise ValueError('The checkpoint has not been found.')
             pt_encoder = self.ts_encoder
@@ -490,7 +495,7 @@ class mtse:
         else:
             try:
                 print('\t\t loading saved weights of the best model at epoch', checkpoint['epoch']) 
-                pt_model = torch.load(checkpoint)
+                pt_model = torch.load(checkpoint, map_location=self.device)
             except:
                 raise ValueError('The checkpoint has not been found.')
             pt_encoder = self.ts_encoder
